aboutsummaryrefslogtreecommitdiffhomepage
path: root/helper/bwrap/builder.go
diff options
context:
space:
mode:
Diffstat (limited to 'helper/bwrap/builder.go')
-rw-r--r--helper/bwrap/builder.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/helper/bwrap/builder.go b/helper/bwrap/builder.go
index e6685aa9..a9481921 100644
--- a/helper/bwrap/builder.go
+++ b/helper/bwrap/builder.go
@@ -63,10 +63,10 @@ func (c *Config) Bind(src, dest string, opts ...bool) *Config {
}
}
// Write copy from FD to destination DEST
// (--file FD DEST)
-func (c *Config) Write(dest string, payload []byte) *Config {
- c.Filesystem = append(c.Filesystem, &DataConfig{Dest: dest, Data: payload, Type: DataWrite})
+func (c *Config) WriteFile(name string, data []byte) *Config {
+ c.Filesystem = append(c.Filesystem, &DataConfig{Dest: name, Data: data, Type: DataWrite})
return c
}
@@ -63,10 +63,10 @@ func (c *Config) Bind(src, dest string, opts ...bool) *Config {
}
}
-// Write copy from FD to destination DEST
+// WriteFile copy from FD to destination DEST
// (--file FD DEST)